/*
  Xinvest Copyright (c)1997-98, 2000
  Mark Buser, All Rights Reserved.

  Permission is hereby granted to copy
  and freely distribute copies of this
  program for non-commercial purposes
  without fee, provided that this notice
  appears in all copies.
  
  All redistributions must be in their
  entirety as originally distributed.
  Feel free to modify Xinvest, but
  modified versions may not be distributed
  without prior consent of the author.
  
  This software is provided 'as-is'
  without any express or implied warranty.
  In no event will the author be held
  liable for any damages resulting from
  the use of this software.

  $Revision: 1.7 $ $Date: 2000/01/12 01:28:26 $
*/
#ifndef PIXNAME_H
#define PIXNAME_H

enum { 
       PSTOP, PABOUT, PRETURN, PCALC, PGRAPH, PPORTFOLIO, PEDIT,
       PSAVE, PNEW, POPEN, PPREV, PNEXT, 
       PDAY, PWEEK, PMONTH, PQTR, PYEAR, PYTD, PFIRST, PPICK,
       P2YEAR, P3YEAR, P5YEAR, P10YEAR,
       PCHECK, PX, 
       PACCT, PACCTS, PFOLD,
       PBAR, PLINE,
       PLAST, PNEXTTRANS, PPREVTRANS,
       PINFO, PSTIPPLE, PFV, PSFV, PPER, PPV, PRATE, PICON, PTICON
} Pixmaps;

#define LASTINSENS PLAST
#define LASTPIXMAP PTICON
#endif
